==> ejc-salary-api-3.0.0-20241129.100427-77-sources.jar: com/ejianc/business/salary/vo/JsAdjustVO.java <==
package com.ejianc.business.salary.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 应发公积金调整
 * 
 * @author generator
 * 
 */
public class JsAdjustVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    

    private BigDecimal personEndowmentMny; // 个人养老金额
    private BigDecimal personMedicalMny; // 个人医疗金额
    private BigDecimal personUnemploymentMny; // 个人失业金额
    private BigDecimal personHouseMny; // 个人公积金
    private BigDecimal companyEndowmentMny; // 公司养老金额
    private BigDecimal companyMedicalMny; // 公司医疗金额
    private BigDecimal companyUnemploymentMny; // 公司失业金额
    private BigDecimal companyBirthMny; // 公司生育金额
    private BigDecimal companyInjureMny; // 公司工伤金额
    private BigDecimal companyHouseMny; // 公司公积金
    private List<JspayableAdjustVO> jspayableAdjustList = new ArrayList<>(); //应发公积金调整明细

    public List<JspayableAdjustVO> getJspayableAdjustList() {
        return jspayableAdjustList;
    }

    public void setJspayableAdjustList(List<JspayableAdjustVO> jspayableAdjustList) {
        this.jspayableAdjustList = jspayableAdjustList;
    }

    public BigDecimal getPersonEndowmentMny() {
        return personEndowmentMny;
    }

    public void setPersonEndowmentMny(BigDecimal personEndowmentMny) {
        this.personEndowmentMny = personEndowmentMny;
    }

    public BigDecimal getPersonMedicalMny() {
        return personMedicalMny;
    }

    public void setPersonMedicalMny(BigDecimal personMedicalMny) {
        this.personMedicalMny = personMedicalMny;
    }

    public BigDecimal getPersonUnemploymentMny() {
        return personUnemploymentMny;
    }

    public void setPersonUnemploymentMny(BigDecimal personUnemploymentMny) {
        this.personUnemploymentMny = personUnemploymentMny;
    }

    public BigDecimal getPersonHouseMny() {
        return personHouseMny;
    }

    public void setPersonHouseMny(BigDecimal personHouseMny) {
        this.personHouseMny = personHouseMny;
    }

    public BigDecimal getCompanyEndowmentMny() {
        return companyEndowmentMny;
    }

    public void setCompanyEndowmentMny(BigDecimal companyEndowmentMny) {
        this.companyEndowmentMny = companyEndowmentMny;
    }

    public BigDecimal getCompanyMedicalMny() {
        return companyMedicalMny;
    }

    public void setCompanyMedicalMny(BigDecimal companyMedicalMny) {
        this.companyMedicalMny = companyMedicalMny;
    }

    public BigDecimal getCompanyUnemploymentMny() {
        return companyUnemploymentMny;
    }

    public void setCompanyUnemploymentMny(BigDecimal companyUnemploymentMny) {
        this.companyUnemploymentMny = companyUnemploymentMny;
    }

    public BigDecimal getCompanyBirthMny() {
        return companyBirthMny;
    }

    public void setCompanyBirthMny(BigDecimal companyBirthMny) {
        this.companyBirthMny = companyBirthMny;
    }

    public BigDecimal getCompanyInjureMny() {
        return companyInjureMny;
    }

    public void setCompanyInjureMny(BigDecimal companyInjureMny) {
        this.companyInjureMny = companyInjureMny;
    }

    public BigDecimal getCompanyHouseMny() {
        return companyHouseMny;
    }

    public void setCompanyHouseMny(BigDecimal companyHouseMny) {
        this.companyHouseMny = companyHouseMny;
    }
}

==> ejc-salary-api-3.0.0-20250826.084018-174-sources.jar: com/ejianc/business/salary/vo/JsAdjustVO.java <==
package com.ejianc.business.salary.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;


/**
 * 应发公积金调整
 * 
 * @author generator
 * 
 */
public class JsAdjustVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    

    private BigDecimal personEndowmentMny; // 个人养老金额
    private BigDecimal personMedicalMny; // 个人医疗金额
    private BigDecimal personUnemploymentMny; // 个人失业金额
    private BigDecimal personHouseMny; // 个人公积金
    private BigDecimal companyEndowmentMny; // 公司养老金额
    private BigDecimal companyMedicalMny; // 公司医疗金额
    private BigDecimal companyUnemploymentMny; // 公司失业金额
    private BigDecimal companyBirthMny; // 公司生育金额
    private BigDecimal companyInjureMny; // 公司工伤金额
    private BigDecimal companyHouseMny; // 公司公积金
    private List<JspayableAdjustVO> jspayableAdjustList = new ArrayList<>(); //应发公积金调整明细
    private BigDecimal criticalIllnessMny; // 大病医保

    public BigDecimal getCriticalIllnessMny() {
        return criticalIllnessMny;
    }

    public void setCriticalIllnessMny(BigDecimal criticalIllnessMny) {
        this.criticalIllnessMny = criticalIllnessMny;
    }
    public List<JspayableAdjustVO> getJspayableAdjustList() {
        return jspayableAdjustList;
    }

    public void setJspayableAdjustList(List<JspayableAdjustVO> jspayableAdjustList) {
        this.jspayableAdjustList = jspayableAdjustList;
    }

    public BigDecimal getPersonEndowmentMny() {
        return personEndowmentMny;
    }

    public void setPersonEndowmentMny(BigDecimal personEndowmentMny) {
        this.personEndowmentMny = personEndowmentMny;
    }

    public BigDecimal getPersonMedicalMny() {
        return personMedicalMny;
    }

    public void setPersonMedicalMny(BigDecimal personMedicalMny) {
        this.personMedicalMny = personMedicalMny;
    }

    public BigDecimal getPersonUnemploymentMny() {
        return personUnemploymentMny;
    }

    public void setPersonUnemploymentMny(BigDecimal personUnemploymentMny) {
        this.personUnemploymentMny = personUnemploymentMny;
    }

    public BigDecimal getPersonHouseMny() {
        return personHouseMny;
    }

    public void setPersonHouseMny(BigDecimal personHouseMny) {
        this.personHouseMny = personHouseMny;
    }

    public BigDecimal getCompanyEndowmentMny() {
        return companyEndowmentMny;
    }

    public void setCompanyEndowmentMny(BigDecimal companyEndowmentMny) {
        this.companyEndowmentMny = companyEndowmentMny;
    }

    public BigDecimal getCompanyMedicalMny() {
        return companyMedicalMny;
    }

    public void setCompanyMedicalMny(BigDecimal companyMedicalMny) {
        this.companyMedicalMny = companyMedicalMny;
    }

    public BigDecimal getCompanyUnemploymentMny() {
        return companyUnemploymentMny;
    }

    public void setCompanyUnemploymentMny(BigDecimal companyUnemploymentMny) {
        this.companyUnemploymentMny = companyUnemploymentMny;
    }

    public BigDecimal getCompanyBirthMny() {
        return companyBirthMny;
    }

    public void setCompanyBirthMny(BigDecimal companyBirthMny) {
        this.companyBirthMny = companyBirthMny;
    }

    public BigDecimal getCompanyInjureMny() {
        return companyInjureMny;
    }

    public void setCompanyInjureMny(BigDecimal companyInjureMny) {
        this.companyInjureMny = companyInjureMny;
    }

    public BigDecimal getCompanyHouseMny() {
        return companyHouseMny;
    }

    public void setCompanyHouseMny(BigDecimal companyHouseMny) {
        this.companyHouseMny = companyHouseMny;
    }
}
